#[repr(u8)]pub enum Ctmode {
TIMER = 0,
COUNTER_RISING_EDGE = 1,
COUNTER_FALLING_EDGE = 2,
COUNTER_DUAL_EDGE = 3,
}Variants
TIMER = 0
Timer Mode. Incremented every rising APB bus clock edge.
COUNTER_RISING_EDGE = 1
Counter Mode rising edge. TC is incremented on rising edges on the CAP input selected by bits 3:2.
COUNTER_FALLING_EDGE = 2
Counter Mode falling edge. TC is incremented on falling edges on the CAP input selected by bits 3:2.
COUNTER_DUAL_EDGE = 3
Counter Mode dual edge. TC is incremented on both edges on the CAP input selected by bits 3:2.
Implementations